@@ -206,12 +206,12 @@ KQuoteMsgID_QuerySecurityInfoReq = Quote_Message_pb2.KQuoteMsgID_QuerySecurityIn
 KQuoteMsgID_QuerySecurityInfoRsp = Quote_Message_pb2.KQuoteMsgID_QuerySecurityInfoRsp
 KQuoteMsgID_QuoteQuery = Quote_Message_pb2.KQuoteMsgID_QuoteQuery
 KQuoteMsgID_QuoteQueryAck = Quote_Message_pb2.KQuoteMsgID_QuoteQueryAck
-KQuoteMsgID_QuoteRegister = Quote_Message_pb2.KQuoteMsgID_QuoteRegister
 KQuoteMsgID_QuoteSnapshot = Quote_Message_pb2.KQuoteMsgID_QuoteSnapshot
-KQuoteMsgID_RegisterAck = Quote_Message_pb2.KQuoteMsgID_RegisterAck
+KQuoteMsgID_Subscribe = Quote_Message_pb2.KQuoteMsgID_Subscribe
+KQuoteMsgID_SubscribeAck = Quote_Message_pb2.KQuoteMsgID_SubscribeAck
 KQuoteMsgID_TimeStamp = Quote_Message_pb2.KQuoteMsgID_TimeStamp
-KQuoteMsgID_UnRegister = Quote_Message_pb2.KQuoteMsgID_UnRegister
-KQuoteMsgID_UnRegisterAck = Quote_Message_pb2.KQuoteMsgID_UnRegisterAck
+KQuoteMsgID_UnSubscribe = Quote_Message_pb2.KQuoteMsgID_UnSubscribe
+KQuoteMsgID_UnSubscribeAck = Quote_Message_pb2.KQuoteMsgID_UnSubscribeAck
 KQuoteMsgID_Unknown = Quote_Message_pb2.KQuoteMsgID_Unknown
 KQuoteRetCode_HasError = Quote_Message_pb2.KQuoteRetCode_HasError
 KQuoteRetCode_Sucess = Quote_Message_pb2.KQuoteRetCode_Sucess
