@@ -243,7 +243,8 @@ _pyb.RegisterConvertor(
 _pyb.RegisterConvertor(
     _pyb.DecimalConfigurator("price_decimal_place",
                              normal_attrs=("traded_amount", "total_fee", "frozen_margin", "frozen_price")),
-    _pyb.DatetimeConfigurator(report_time="%Y%m%d-%H:%M:%S.%f"),
+    # _pyb.DatetimeConfigurator(report_time="%Y%m%d-%H:%M:%S.%f"),
+    _pyb.MultiDatetimeConfigurator(report_time=("%Y%m%d-%H:%M:%S.%f", "%Y%m%d-%H%M%S.%f")),
     protobuf=MsgProto.Trade_OrdStatusMsg
 ).SetPyHandles(
     _pyb.PyEnumReprHandle(order_status=EnumProto.EOrderStatus, reject_reason=EnumProto.EOrderRejectReason)
