@@ -21,6 +21,8 @@ import threading
 import time
 import typing
 from threading import Event
+from traceback import format_exc
+
 from .qujam_thread import QujamThread
 
 
@@ -138,10 +140,13 @@ class QujamLoopThread:
                         break
                     ret_cb(ret)
                 except Exception as err:
+                    # exc_traceback = format_exc()
+                    # print(exc_traceback)
                     if err.__class__ in finish_exc:
                         break
                     if not err_cb(err):
                         func_error = err
+
                     break
                 fn_ptime()
             if not finish_cb(now_thread, func_error) and func_error:
